SystemOrganization addCategory: #'CS528-Project'!

ZnWebSocket subclass: #TableWebsocket
	instanceVariableNames: 'tableID delegate'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project'!

!TableWebsocket commentStamp: '<historical>' prior: 0!
A TableWebsocket is an abstraction over the websocket connection between a PokerPlayer and the PokerTable they are currently a member of. It is a reference maintained by the PokerPlayer so that 

Instance Variables
	delegate:		<PokerPlayer>
	tableID:		<string>

delegate
	- PokerPlayer which will be required to handle incoming messages on this websocket. Must implement onMessage: message.

tableID
	- string representing the ID of the table this websocket is connected to.
!

!TableWebsocket class methodsFor: 'initialize' stamp: 'BrianDentino 7/11/2013 21:45'!
tableID: id delegate: aDelegate 
	^ ((TableWebsocket to: 'ws://localhost:', ZnServer default port asString, '/', id) tableID: id) delegate: aDelegate.! !

!TableWebsocket methodsFor: 'initialize-release' stamp: 'lb 6/13/2013 21:46'!
delegate: aDelegate
	delegate := aDelegate.
	[[self runWith: [ :message |
      	self crLog: 'PokerPlayer received message from table: ', message printString. 
		delegate onMessage: message from: self].] on: ConnectionClosed do: [ self log debug: '==Connection Closed'] ] fork.! !

!TableWebsocket methodsFor: 'as yet unclassified' stamp: 'BrianDentino 7/11/2013 23:08'!
initialize
	super initialize.
	self role: #server.! !

!TableWebsocket methodsFor: 'initialize-release' stamp: 'BrianDentino 7/6/2013 22:24'!
tableID: id
	tableID := id! !

WAComponent subclass: #BetButton
	instanceVariableNames: 'betCallback'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project'!

!BetButton commentStamp: '<historical>' prior: 0!
A BetButton is a simple button that evaluates 'betCallback' when clicked.

Instance Variables
	betCallback:		<Block> 

betCallback
	- Callback to be evaluated when button is clicked. Should not expect any arguments.
!

!BetButton class methodsFor: 'as yet unclassified' stamp: 'BrianDentino 7/14/2013 20:31'!
onBet: aCallback
	^(self new onBet: aCallback).! !

!BetButton methodsFor: 'rendering' stamp: 'BrianDentino 7/14/2013 20:31'!
onBet: aCallback
	betCallback := aCallback.! !

!BetButton methodsFor: 'rendering' stamp: 'BrianDentino 7/15/2013 23:00'!
renderContentOn: html
	html submitButton 
		onClick: ( html jQuery ajax
			callback: [ betCallback value ] );
		with: 'Bet'.! !

WAComponent subclass: #BetSlider
	instanceVariableNames: 'min max step betAmount'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project'!

!BetSlider commentStamp: '<historical>' prior: 0!
A BetSlider is a renderable component that presents a slider and label indicating the current value of the slider.

Instance Variables
	betAmount:		<Number> current bet
	max:		<Number> max slider value
	min:		<Number> min slider value
	step:		<Number> slider increment interval

betAmount
	- xxxxx

max
	- xxxxx

min
	- xxxxx

step
	- xxxxx
!

!BetSlider class methodsFor: 'initialize' stamp: 'BrianDentino 7/15/2013 23:08'!
min: minValue max: maxValue step: stepValue
	^ (self new) min: minValue; max: maxValue; step: stepValue.! !

!BetSlider methodsFor: 'accessing' stamp: 'BrianDentino 7/15/2013 22:34'!
betAmount
	^betAmount.! !

!BetSlider methodsFor: 'accessing' stamp: 'BrianDentino 7/16/2013 04:13'!
betAmount: anAmount
	betAmount := anAmount.! !

!BetSlider methodsFor: 'initialize' stamp: 'BrianDentino 7/15/2013 23:12'!
initialize
	super initialize. 
	min := 0.
	max := 0.
	step := 0.
	betAmount := 0.! !

!BetSlider methodsFor: 'accessing' stamp: 'BrianDentino 7/15/2013 23:09'!
max: aValue
	max := aValue! !

!BetSlider methodsFor: 'accessing' stamp: 'BrianDentino 7/16/2013 02:54'!
min: aValue
	min := aValue.
	betAmount := min! !

!BetSlider methodsFor: 'rendering' stamp: 'BrianDentino 7/16/2013 04:17'!
renderContentOn: html
	| labelID sliderID |
	
	labelID := html nextId.
	sliderID := html nextId.
	
	html div 
		id: sliderID;
		script: (html jQuery new slider
			min: min;
			max: max;
			step: step;
			value: betAmount;
			orientation: #vertical;
			onSlide: [ :value | ( html jQuery script: [ :s | s << (s jQuery id: labelID) text: value ] ) ]
			
			"; 
			Not actually using this anymore, but leaving it in as documentation for how to setup ajax callbacks.
			
			onChange: [ :value | ( html jQuery ajax 
				callback: [ :amount | self betAmount: amount asNumber ] value: (value) ) ] ).
			"
			
			).
		
	html space.
	html space.
	html div id: labelID;
		with: betAmount! !

!BetSlider methodsFor: 'accessing' stamp: 'BrianDentino 7/15/2013 23:09'!
step: aValue
	step := aValue! !

WAComponent subclass: #DrawButton
	instanceVariableNames: 'drawCallback'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project'!

!DrawButton class methodsFor: 'as yet unclassified' stamp: 'lb 6/13/2013 22:12'!
onDraw: aCallback
	^(self new onDraw: aCallback).! !

!DrawButton methodsFor: 'as yet unclassified' stamp: 'lb 6/13/2013 22:31'!
onDraw: aCallback
	drawCallback := aCallback.! !

!DrawButton methodsFor: 'as yet unclassified' stamp: 'lb 6/13/2013 22:11'!
renderContentOn: html
	html submitButton 
		onClick: ( html jQuery ajax
			callback: [drawCallback value ] );
		with: 'Draw'.! !

WAComponent subclass: #PokerPlayerView
	instanceVariableNames: 'playerID tableID table browser'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project'!

PokerPlayerView class
	instanceVariableNames: 'nextID'!

!PokerPlayerView commentStamp: '<historical>' prior: 0!
A PokerPlayer is a Seaside component that manages client decisions. When the state of a game changes, the PokerPlayer class notifies the view via a websocket connection to the browser.

Instance Variables
!

PokerPlayerView class
	instanceVariableNames: 'nextID'!

!PokerPlayerView class methodsFor: 'initialize' stamp: 'BrianDentino 7/12/2013 02:13'!
initialize 
	super initialize.
	nextID := 0.! !

!PokerPlayerView class methodsFor: 'as yet unclassified' stamp: 'BrianDentino 7/12/2013 02:17'!
nextID
	nextID := nextID + 1.
	^ nextID asString.! !

!PokerPlayerView class methodsFor: 'initialize' stamp: 'lb 6/13/2013 19:18'!
tableID: table
	^(self new tableID: table playerID: PokerPlayerView nextID)! !

!PokerPlayerView methodsFor: 'accessing' stamp: 'BrianDentino 7/12/2013 01:47'!
close
	table close.! !

!PokerPlayerView methodsFor: 'accessing' stamp: 'lb 7/18/2013 01:42'!
comm

	table sendMessage: (WebsocketMessage id: 'comm' content: '') json.! !

!PokerPlayerView methodsFor: 'accessing' stamp: 'lb 7/18/2013 01:42'!
draw

	table sendMessage: (WebsocketMessage id: 'draw' content: '') json.! !

!PokerPlayerView methodsFor: 'as yet unclassified' stamp: 'lb 7/18/2013 00:50'!
initialize 
	super initialize.
	browser := BrowserWebsocket delegate: self.! !

!PokerPlayerView methodsFor: 'accessing' stamp: 'lb 7/18/2013 00:49'!
onMessage: aMessage from: websocket
	(websocket == table) ifTrue: [ browser sendMessage: aMessage ].
	(websocket == browser) ifTrue: [ table sendMessage: aMessage ].! !

!PokerPlayerView methodsFor: 'rendering' stamp: 'lb 7/18/2013 01:24'!
placeBet: anAmount 

	| action |
	
	action := Dictionary new.
	action at: 'actionType' put: 'bet'.
	action at: 'amount'put: anAmount.
	
	self sendPlayerAction: action! !

!PokerPlayerView methodsFor: 'accessing' stamp: 'lb 7/13/2013 15:16'!
playerID
	^ playerID! !

!PokerPlayerView methodsFor: 'rendering' stamp: 'lb 7/18/2013 00:26'!
renderContentOn: html
	| betSlider |

	betSlider := BetSlider min: 5 max: 100 step: 5.

	html text: 'Welcome to table ', tableID.
	html horizontalRule.
	
	html render: (BetButton onBet: [ self placeBet: betSlider betAmount ]).
	html horizontalRule.
	
	html render: betSlider.
	html horizontalRule.
	
	html heading level: 2; with: 'Players:'.
	html div id: 'players'.
	
	html heading level: 2; with: 'My Cards:'.
	html div id: 'cards'.
	
	html render: (DrawButton onDraw: [self draw]).
	html horizontalRule.
	
	html heading level: 2; with: 'The Board'.
	html div id: 'theBoard'.
	
	html render: (DrawButton onDraw: [self comm]).
	html horizontalRule.
	
	html heading level: 2; with: 'Previous Actions:'.
	html div id: 'updatePlayerAction'.
	
	html render: (TestJSComponent wsAddress: 'ws://localhost:1701/', tableID, '_', playerID).! !

!PokerPlayerView methodsFor: 'rendering' stamp: 'lb 7/18/2013 01:24'!
sendPlayerAction: anAction

	table sendMessage: (WebsocketMessage id: 'playerAction' content: anAction) json.! !

!PokerPlayerView methodsFor: 'rendering' stamp: 'BrianDentino 7/15/2013 23:32'!
style
	^ ''
	"'
	.ui-slider-vertical {
		width: .4em;
	}
	
	.ui-slider .ui-slider-handle {
		position: absolute;
		z-index: 2;
		width: .8em;
		height: .4em;
		cursor: default;
	}
	
	.ui-slider-vertical .ui-slider-handle {
		top: 0em;
		margin-left: 0em;
	}
	'"! !

!PokerPlayerView methodsFor: 'accessing' stamp: 'BrianDentino 7/6/2013 21:29'!
tableID
	^tableID! !

!PokerPlayerView methodsFor: 'accessing' stamp: 'lb 6/13/2013 19:24'!
tableID:  aTableID playerID: aPlayerID
	| url |
	tableID := aTableID.
	playerID := aPlayerID.
	url := tableID, '_', playerID.
	table := TableWebsocket tableID: tableID delegate: self.
	
	ZnServer default delegate map: url to: (ZnWebSocketDelegate map: url to: browser).! !

WAComponent subclass: #ProjectLanding
	instanceVariableNames: ''
	classVariableNames: 'tables'
	poolDictionaries: ''
	category: 'CS528-Project'!

ProjectLanding class
	instanceVariableNames: 'tables'!

!ProjectLanding commentStamp: '<historical>' prior: 0!
A ProjectLanding is a Seaside component that renders a page which allows users to create or join tables for hosting/playing poker games.

Instance Variables
	tables:		<Object>

tables
	- a dictionary of all active tables. key (tableID) maps to PokerTable object.
!

ProjectLanding class
	instanceVariableNames: 'tables'!

!ProjectLanding class methodsFor: 'as yet unclassified' stamp: 'BrianDentino 7/5/2013 22:42'!
canBeRoot
	^ true! !

!ProjectLanding class methodsFor: 'testing' stamp: 'BrianDentino 7/16/2013 02:49'!
initialize 
	"ProjectLanding initialize"
	
	(WAAdmin register: self asApplicationAt: 'landing')
		addLibrary: JQDeploymentLibrary;
		addLibrary: JQUiDeploymentLibrary;
		addLibrary: JQCupertinoTheme.
	tables := Dictionary new.! !

!ProjectLanding class methodsFor: 'testing' stamp: 'BrianDentino 7/12/2013 01:00'!
tables
	^tables.! !

!ProjectLanding methodsFor: 'setup' stamp: 'BrianDentino 7/12/2013 01:00'!
createNewTable
	| id |
	id := self request: 'Enter a Table ID:'.
	(ProjectLanding tables) at: id put: (PokerTable id: id).
	self joinTable: id.! !

!ProjectLanding methodsFor: 'initialization' stamp: 'BrianDentino 7/12/2013 00:57'!
initialize 
	super initialize.! !

!ProjectLanding methodsFor: 'setup' stamp: 'BrianDentino 7/12/2013 01:06'!
joinExistingTable
	| id |
	id := self requestTableID.
	self joinTable: id.
	! !

!ProjectLanding methodsFor: 'setup' stamp: 'BrianDentino 7/15/2013 23:20'!
joinTable: tableID
	self call: (PokerPlayerView tableID: tableID).
	! !

!ProjectLanding methodsFor: 'rendering' stamp: 'BrianDentino 7/14/2013 14:49'!
renderContentOn: html
	html heading: 'Welcome to Smalltalk Casino!!'.
	html anchor
		callback: [ self createNewTable. ];
		with: 'Start a table'.
	html space.
	html anchor
		callback: [ self joinExistingTable. ];
		with: 'Join a table'.! !

!ProjectLanding methodsFor: 'setup' stamp: 'BrianDentino 7/6/2013 02:09'!
requestTableID
	| id |
	id := self request: 'Enter a Table ID:'.
	^id! !

!ProjectLanding methodsFor: 'as yet unclassified' stamp: 'BrianDentino 7/5/2013 22:46'!
states
	^ Array with: self.! !

WAComponent subclass: #TestJSComponent
	instanceVariableNames: 'wsAddress id'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project'!

!TestJSComponent commentStamp: '<historical>' prior: 0!
A TestJSComponent is a simple Seaside component that establishes a websocket connection between the rendering browser and a websocket server at the address held in wsAddress.

Instance Variables
	wsAddress:		<string>

wsAddress
	- string representation of the websocket address
	i.e. 'ws://10.0.0.3:8888/client'
!

!TestJSComponent class methodsFor: 'initialize' stamp: 'BrianDentino 7/11/2013 19:51'!
wsAddress: address
	^ (self new) wsAddress: address.! !

!TestJSComponent methodsFor: 'accessing' stamp: 'BrianDentino 7/12/2013 20:00'!
id
	^id! !

!TestJSComponent methodsFor: 'accessing' stamp: 'BrianDentino 7/12/2013 20:00'!
initialize
	super initialize.
	id := 'websocket'! !

!TestJSComponent methodsFor: 'accessing' stamp: 'lb 7/13/2013 14:06'!
renderContentOn: html

	html script: '	
	var conn = {};
	conn = new WebSocket("', wsAddress, '");
 
	conn.onmessage = function (event) {
	
		var json = event.data;
		var obj = JSON.parse(json); /** TODOhow to get jquery to work?? */
		
		console.log(obj.id);
		console.log(obj.content);
		
		var elt = document.getElementById(obj.id);
		elt.innerHTML = obj.content;
    	};
    
    	conn.onclose = function (event) {
		console.log("connection closed")
    	};
	
'! !

!TestJSComponent methodsFor: 'accessing' stamp: 'BrianDentino 7/11/2013 19:52'!
wsAddress
	^wsAddress! !

!TestJSComponent methodsFor: 'accessing' stamp: 'BrianDentino 7/11/2013 19:52'!
wsAddress: address
	wsAddress := address.! !

Object subclass: #BrowserWebsocket
	instanceVariableNames: 'delegate websocket lock'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project'!

!BrowserWebsocket commentStamp: '<historical>' prior: 0!
A BrowserWebsocket is an abstraction over the websocket connection between a client PokerPlayer and the browser rendering it.

Instance Variables
	delegate:		<Object>

delegate
	- xxxxx
!

!BrowserWebsocket class methodsFor: 'initialize' stamp: 'BrianDentino 7/11/2013 22:20'!
delegate: aDelegate 
	^(self new delegate: aDelegate).! !

!BrowserWebsocket methodsFor: 'initialize-release' stamp: 'BrianDentino 7/11/2013 22:20'!
delegate: aDelegate
	delegate := aDelegate.! !

!BrowserWebsocket methodsFor: 'initialize-release' stamp: 'BrianDentino 7/12/2013 00:05'!
initialize
	lock := Mutex new.! !

!BrowserWebsocket methodsFor: 'initialize-release' stamp: 'lb 7/12/2013 16:25'!
sendMessage: aMessage
	websocket isNil ifTrue: [ Transcript show: 'browser websocket not ready yet...' ]
		ifFalse: [ websocket sendMessage: aMessage ].! !

!BrowserWebsocket methodsFor: 'initialize-release' stamp: 'lb 7/18/2013 01:42'!
value: aWebsocket 
	websocket := aWebsocket.
	
	lock critical: [ delegate 
		onMessage: ((WebsocketMessage id: 'joining' content:  (delegate playerID)) json) 
		from: self. ].
		
	[ websocket runWith: [ :message |
		websocket log info: [
			 'PokerPlayer received message from browser: ', message printString. 
		].
		lock critical: [ delegate onMessage: message from: self. ].
	]. ]
	on: ConnectionClosed 
	do: [ 
		websocket log debug: '**Connection close, cleaning up'.
		delegate close.
	].! !

!BrowserWebsocket methodsFor: 'as yet unclassified' stamp: 'lb 7/12/2013 13:42'!
websocket
^ websocket! !

Object subclass: #PokerTable
	instanceVariableNames: 'id lock players'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project'!

!PokerTable commentStamp: '<historical>' prior: 0!
A PokerTable is a container for clients playing poker together. Each client is represented by a websocket. When the game state is updated, the table broadcasts updates to each of the clients.

Instance Variables
!

!PokerTable class methodsFor: 'as yet unclassified' stamp: 'BrianDentino 7/6/2013 20:06'!
id: anIdentifier 
	^ PokerTable new id: anIdentifier.! !

!PokerTable methodsFor: 'accessing' stamp: 'lb 7/18/2013 01:03'!
addCommunityCard: aCard
	
	self broadcast: (WebsocketMessage id: 'theBoard' content: aCard shortForm) json! !

!PokerTable methodsFor: 'accessing' stamp: 'lb 7/18/2013 01:38'!
addPlayer: aPlayerID at: aWebsocket

	| stream msg |	
	
	players at: aPlayerID put: aWebsocket.
		
	stream := String new writeStream.
	stream nextPutAll: '<ul>'.
	players keysDo: [ :playerID | stream nextPutAll: '<li>', playerID, '</li>' ].
	stream nextPutAll: '</ul>'.
	
	msg := (WebsocketMessage id: 'players' content: stream contents) json.
	
	self broadcast: msg.
	! !

!PokerTable methodsFor: 'websocket' stamp: 'lb 6/13/2013 21:48'!
broadcast: aMessage
	"Send message to all connected clients"
	lock critical: [ 
		players keysAndValuesDo: [  :playerID :ws |
			[ ws sendMessage: aMessage ]
				on: NetworkError
				do: [  :exception | 
					ws log debug: [ exception printString, ' NetworkError in broadcast...ignoring' ] ] ] ]! !

!PokerTable methodsFor: 'protocol' stamp: 'lb 6/13/2013 21:50'!
clear
	players keysDo: [ :playerID | players removeKey: playerID.  ] ! !

!PokerTable methodsFor: 'accessing' stamp: 'lb 7/18/2013 01:10'!
dealCard: aCard to: aPlayerID

	(players at: aPlayerID) sendMessage: (WebsocketMessage id: 'cards' content: aCard shortForm) json.! !

!PokerTable methodsFor: 'accessing' stamp: 'lb 7/17/2013 21:58'!
gameFlowMessage: aString
	self halt.! !

!PokerTable methodsFor: 'accessing' stamp: 'lb 7/17/2013 21:58'!
getPlayerAction: aPlayerID
	self halt.! !

!PokerTable methodsFor: 'accessing' stamp: 'BrianDentino 7/6/2013 18:50'!
id
	^id! !

!PokerTable methodsFor: 'accessing' stamp: 'BrianDentino 7/11/2013 23:27'!
id: anIdentifier 
	id := anIdentifier.
	ZnServer default delegate map: id to: (ZnWebSocketDelegate map: id to: self).! !

!PokerTable methodsFor: 'initialize-release' stamp: 'lb 6/13/2013 21:49'!
initialize 
	players := Dictionary new.
	lock := Mutex new.! !

!PokerTable methodsFor: 'accessing' stamp: 'lb 6/13/2013 21:48'!
players
	^ players! !

!PokerTable methodsFor: 'protocol' stamp: 'lb 6/13/2013 21:49'!
register: clientWebSocket
	Transcript show: 'shouldn''t be calling register...'
"	lock critical: [ 
		players at: id add: clientWebSocket ]."! !

!PokerTable methodsFor: 'protocol' stamp: 'lb 6/13/2013 21:48'!
unregister: clientWebSocket
	lock critical: [ 
		players keysAndValuesDo: [ :playerID :ws | ws = clientWebSocket ifTrue: [ players removeKey: playerID.  ] ]  ] .
	(players size = 0) ifTrue: [ProjectLanding tables removeKey: id]! !

!PokerTable methodsFor: 'accessing' stamp: 'lb 7/18/2013 00:56'!
updatePlayerAction: aPlayerAction
	
	self broadcast: (WebsocketMessage id: 'updatePlayerAction' content: aPlayerAction) json.! !

!PokerTable methodsFor: 'protocol' stamp: 'lb 6/13/2013 19:23'!
value: websocket

	| msg handler |

	[ "self register: websocket."
		websocket runWith: [ :message |
			
			websocket log info: [ 'PokerTable received message: ', message printString ].

			msg := WebsocketMessage json: message.

			Transcript show: '*******'; show: msg id; show: msg content.
			
			handler := WebsocketMessageHandlerFactory getHandlerFor: msg. 
			
			handler handleMessage: msg from: websocket to: self.
			
		].
			
	]
	on: ConnectionClosed 
	do: [ 
		websocket log debug: '!!!!Connection close, cleaning up'.
		self unregister: websocket ].! !

Object subclass: #WebsocketMessage
	instanceVariableNames: 'id content'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project'!

!WebsocketMessage commentStamp: '<historical>' prior: 0!
A WebsocketMessage is an object intended to represent a websocket message. It contains an id, so the receiver can identify the type of message, as well as content.

Instance Variables
	content:		<string>
	id:		<string>

content
	- String intended to be interpreted as the content of the message

id
	- String intented to be interpreted as the message identifier.
!

!WebsocketMessage class methodsFor: 'creation' stamp: 'lb 7/13/2013 14:05'!
id: aStringId content: aStringContent 
	^ (self new id: aStringId) content: aStringContent.! !

!WebsocketMessage class methodsFor: 'as yet unclassified' stamp: 'lb 7/13/2013 15:08'!
json: aJsonString

	 |obj |
	
	obj := Json readFrom: (ReadStream on: aJsonString).

	^ WebsocketMessage id: obj id content: obj content! !

!WebsocketMessage methodsFor: 'accessing' stamp: 'BrianDentino 7/12/2013 19:56'!
content
	^content.! !

!WebsocketMessage methodsFor: 'accessing' stamp: 'lb 7/13/2013 14:05'!
content: aString 
	content := aString.! !

!WebsocketMessage methodsFor: 'accessing' stamp: 'BrianDentino 7/12/2013 19:56'!
id
	^id.! !

!WebsocketMessage methodsFor: 'accessing' stamp: 'lb 7/13/2013 14:05'!
id: aString 
	id := aString.! !

!WebsocketMessage methodsFor: 'accessing' stamp: 'lb 7/13/2013 15:05'!
json

	^ Json render: self! !

!WebsocketMessage methodsFor: 'as yet unclassified' stamp: 'lb 7/18/2013 00:47'!
jsonWriteOn: aWriteStream
	
	aWriteStream nextPutAll: '{ "id" : '.
	aWriteStream nextPutAll: (Json render: id).
	aWriteStream nextPutAll: ', "content" : '.
	"content isDictionary ifTrue: [ aWriteStream nextPutAll: '{' ]."
	aWriteStream nextPutAll: (Json render: content).
	"content isDictionary ifTrue: [ aWriteStream nextPutAll: '}' ]."
	aWriteStream nextPutAll: ' }'.
	^ aWriteStream contents! !

Object subclass: #WebsocketMessageHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project'!

WebsocketMessageHandler subclass: #CommMessageHandlerTESTING
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project'!

!CommMessageHandlerTESTING methodsFor: 'as yet unclassified' stamp: 'lb 7/18/2013 01:25'!
handleMessage: aWebsocketMessage from: aWebsocket to: aTable
	" just for testing... the addCommunityCard function should be called by the game not ever the browser message handlers "
	aTable addCommunityCard: (Card newWithSuit: Suit diamonds value: CardValue five)! !

WebsocketMessageHandler subclass: #DrawMessageHandlerTESTING
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project'!

!DrawMessageHandlerTESTING methodsFor: 'as yet unclassified' stamp: 'lb 7/18/2013 01:26'!
handleMessage: aWebsocketMessage from: aWebsocket to: aTable
	" just for testing... the dealCard function should be called by the game not ever the browser message handlers "
	
	| id |
	aTable players keysAndValuesDo: [ :playerID :ws | ws = aWebsocket ifTrue: [ id := playerID] ].
	
	aTable dealCard: (Card newWithSuit: Suit clubs value: CardValue queen) to: id.! !

WebsocketMessageHandler subclass: #JoinMessageHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project'!

!JoinMessageHandler methodsFor: 'as yet unclassified' stamp: 'lb 7/18/2013 01:42'!
handleMessage: aWebsocketMessage from: aWebsocket to: aTable
	
	"adds a player to the dictionary of players... even if a websocket connects the player doesn't officially
	join the game until a Joining message is sent (because we need the playerID)"
	
	"add the player to the game... then somewhere we need to add them to the websocket list as well ** so need websocket here ** "
	aTable addPlayer: aWebsocketMessage content at: aWebsocket.! !

WebsocketMessageHandler subclass: #PlayerActionMessageHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project'!

!PlayerActionMessageHandler methodsFor: 'as yet unclassified' stamp: 'lb 7/18/2013 01:23'!
handleMessage: aWebsocketMessage from: aWebsocket to: aTable "shouldn't need these other 2 args i don't think(?)... just for now"
	
	| jsonObj action |

	jsonObj := aWebsocketMessage content.
	
	action := THPlayerActionFactory new create: jsonObj.
	
	" do something with the action... "
	
	aTable updatePlayerAction: action. " then this line would be after whatever you do with the action... "! !

!WebsocketMessageHandler methodsFor: 'as yet unclassified' stamp: 'lb 7/16/2013 12:57'!
handleMessage: aWebsocketMessage from: aWebsocket to: aTable
	self subclassResponsibility! !

Object subclass: #WebsocketMessageHandlerFactory
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project'!

!WebsocketMessageHandlerFactory class methodsFor: 'as yet unclassified' stamp: 'lb 7/18/2013 01:42'!
getHandlerFor: msg
				
	(msg id = 'playerAction')
		ifTrue: [ ^ PlayerActionMessageHandler new ].	
			
	(msg id = 'joining') 
		ifTrue: [ ^ JoinMessageHandler new. ].	
					
	(msg id = 'draw') 
		ifTrue: [ ^ DrawMessageHandlerTESTING new. ].
	
	(msg id = 'comm')
		ifTrue: [  ^ CommMessageHandlerTESTING new ].		
		
	"Should never reach this point"
	self error: 'Unknown Message ID: ' , msg id.! !
PokerPlayerView initialize!
ProjectLanding initialize!
